largefiles: don't explicitly list optional parameters that are not used
authorTony Tung <tonytung@merly.org>
Mon, 22 Feb 2016 23:18:19 -0800
changeset 28193 19775bc34da3
parent 28190 e8d1460e2a72
child 28194 7623ba92af72
largefiles: don't explicitly list optional parameters that are not used This makes it easier for changes to the API.
hgext/largefiles/overrides.py
--- a/hgext/largefiles/overrides.py	Mon Feb 08 14:07:17 2016 +0100
+++ b/hgext/largefiles/overrides.py	Mon Feb 22 23:18:19 2016 -0800
@@ -452,12 +452,10 @@
 # writing the files into the working copy and lfcommands.updatelfiles
 # will update the largefiles.
 def overridecalculateupdates(origfn, repo, p1, p2, pas, branchmerge, force,
-                             acceptremote, followcopies, matcher=None,
-                             mergeforce=False):
+                             acceptremote, *args, **kwargs):
     overwrite = force and not branchmerge
     actions, diverge, renamedelete = origfn(
-        repo, p1, p2, pas, branchmerge, force, acceptremote,
-        followcopies, matcher=matcher)
+        repo, p1, p2, pas, branchmerge, force, acceptremote, *args, **kwargs)
 
     if overwrite:
         return actions, diverge, renamedelete